@@ -45,6 +45,4 @@ def clearBit(int_type, offset):
     mask = ~(1 << offset)
     return(int_type & mask)
 
-if __name__ == '__main__':
-    test = 1
 
